EXPORTS
	?SetRotationL@CMediaClientVideoDisplay@@QAEXABVRWindowBase@@W4TVideoRotation@@ABVTRect@@@Z @ 1 NONAME ; void CMediaClientVideoDisplay::SetRotationL(class RWindowBase const &, enum TVideoRotation, class TRect const &)
	?RemoveSurface@CMediaClientVideoDisplay@@QAEXXZ @ 2 NONAME ; void CMediaClientVideoDisplay::RemoveSurface(void)
	?SetWindowClipRectL@CMediaClientVideoDisplay@@QAEXABVRWindowBase@@ABVTRect@@1@Z @ 3 NONAME ; void CMediaClientVideoDisplay::SetWindowClipRectL(class RWindowBase const &, class TRect const &, class TRect const &)
	?SetAutoScaleL@CMediaClientVideoDisplay@@QAEXW4TAutoScaleType@@HHABVTRect@@@Z @ 4 NONAME ; void CMediaClientVideoDisplay::SetAutoScaleL(enum TAutoScaleType, int, int, class TRect const &)
	?SetScaleFactorL@CMediaClientVideoDisplay@@QAEXABVRWindowBase@@MMABVTRect@@@Z @ 5 NONAME ; void CMediaClientVideoDisplay::SetScaleFactorL(class RWindowBase const &, float, float, class TRect const &)
	?GetScaleFactorL@CMediaClientVideoDisplay@@QAEXABVRWindowBase@@AAM1@Z @ 6 NONAME ; void CMediaClientVideoDisplay::GetScaleFactorL(class RWindowBase const &, float &, float &)
	?SetRotationL@CMediaClientVideoDisplay@@QAEXW4TVideoRotation@@ABVTRect@@@Z @ 7 NONAME ; void CMediaClientVideoDisplay::SetRotationL(enum TVideoRotation, class TRect const &)
	?NewL@CMediaClientVideoDisplay@@SAPAV1@HABVTSurfaceId@@ABVTRect@@VTVideoAspectRatio@@@Z @ 8 NONAME ; class CMediaClientVideoDisplay * CMediaClientVideoDisplay::NewL(int, class TSurfaceId const &, class TRect const &, class TVideoAspectRatio)
	?SetAutoScaleL@CMediaClientVideoDisplay@@QAEXABVRWindowBase@@W4TAutoScaleType@@HHABVTRect@@@Z @ 9 NONAME ; void CMediaClientVideoDisplay::SetAutoScaleL(class RWindowBase const &, enum TAutoScaleType, int, int, class TRect const &)
	?SetVideoExtentL@CMediaClientVideoDisplay@@QAEXABVRWindowBase@@ABVTRect@@1@Z @ 10 NONAME ; void CMediaClientVideoDisplay::SetVideoExtentL(class RWindowBase const &, class TRect const &, class TRect const &)
	?NewL@CMediaClientVideoDisplay@@SAPAV1@H@Z @ 11 NONAME ; class CMediaClientVideoDisplay * CMediaClientVideoDisplay::NewL(int)
	??1CMediaClientVideoDisplay@@UAE@XZ @ 12 NONAME ; CMediaClientVideoDisplay::~CMediaClientVideoDisplay(void)
	?SurfaceCreated@CMediaClientVideoDisplay@@QAEHABVTSurfaceId@@ABVTRect@@VTVideoAspectRatio@@1@Z @ 13 NONAME ; int CMediaClientVideoDisplay::SurfaceCreated(class TSurfaceId const &, class TRect const &, class TVideoAspectRatio, class TRect const &)
	?RotationL@CMediaClientVideoDisplay@@QAE?AW4TVideoRotation@@ABVRWindowBase@@@Z @ 14 NONAME ; enum TVideoRotation CMediaClientVideoDisplay::RotationL(class RWindowBase const &)
	?RedrawWindows@CMediaClientVideoDisplay@@QAEHABVTRect@@@Z @ 15 NONAME ; int CMediaClientVideoDisplay::RedrawWindows(class TRect const &)
	?AddDisplayWindowL@CMediaClientVideoDisplay@@QAEXPBVRWindowBase@@ABVTRect@@11MMW4TVideoRotation@@W4TAutoScaleType@@HHPAVRWindow@@@Z @ 16 NONAME ; void CMediaClientVideoDisplay::AddDisplayWindowL(class RWindowBase const *, class TRect const &, class TRect const &, class TRect const &, float, float, enum TVideoRotation, enum TAutoScaleType, int, int, class RWindow *)
	?RemoveDisplayWindow@CMediaClientVideoDisplay@@QAEHABVRWindowBase@@@Z @ 17 NONAME ; int CMediaClientVideoDisplay::RemoveDisplayWindow(class RWindowBase const &)
	?SurfaceParametersChanged@CMediaClientVideoDisplay@@QAEHABVTSurfaceId@@ABVTRect@@VTVideoAspectRatio@@@Z @ 18 NONAME ; int CMediaClientVideoDisplay::SurfaceParametersChanged(class TSurfaceId const &, class TRect const &, class TVideoAspectRatio)
	?SetScaleFactorL@CMediaClientVideoDisplay@@QAEXMMABVTRect@@@Z @ 19 NONAME ; void CMediaClientVideoDisplay::SetScaleFactorL(float, float, class TRect const &)
	?SetExternalDisplaySwitchingL@CMediaClientVideoDisplay@@QAEXH@Z @ 20 NONAME ; void CMediaClientVideoDisplay::SetExternalDisplaySwitchingL(int)	
	??1CExtDisplayConnectionProviderInterface@@UAE@XZ @ 21 NONAME ; CExtDisplayConnectionProviderInterface::~CExtDisplayConnectionProviderInterface(void)
	??0CExtDisplayConnectionProviderInterface@@IAE@XZ @ 22 NONAME ; CExtDisplayConnectionProviderInterface::CExtDisplayConnectionProviderInterface(void)
	

